@@ -19,12 +19,14 @@
 
 #include "deleteacljob.h"
 
+#include <KLocalizedString>
+
 #include "acljobbase_p.h"
 #include "message_p.h"
 #include "session_p.h"
 #include "rfccodecs.h"
 
-namespace KIMAP2
+namespace KIMAP
 {
 class DeleteAclJobPrivate : public AclJobBasePrivate
 {
@@ -34,13 +36,13 @@ public:
 };
 }
 
-using namespace KIMAP2;
+using namespace KIMAP;
 
 DeleteAclJob::DeleteAclJob(Session *session)
     : AclJobBase(session)
 {
     Q_D(DeleteAclJob);
-    d->m_name = "DeleteAclJob";
+    d->m_name = i18n("DeleteAclJob");
 }
 
 DeleteAclJob::~DeleteAclJob()
@@ -51,7 +53,7 @@ void DeleteAclJob::doStart()
 {
     Q_D(DeleteAclJob);
 
-    d->sendCommand("DELETEACL", '\"' + KIMAP2::encodeImapFolderName(d->mailBox.toUtf8()) + "\" \"" + d->id);
+    d->tags << d->sessionInternal()->sendCommand("DELETEACL", '\"' + KIMAP::encodeImapFolderName(d->mailBox.toUtf8()) + "\" \"" + d->id);
 }
 
 void DeleteAclJob::setIdentifier(const QByteArray &identifier)
