@@ -19,6 +19,7 @@
 
 #include "selectjob.h"
 
+#include <KLocalizedString>
 #include "kimap_debug.h"
 
 #include "job_p.h"
@@ -26,7 +27,7 @@
 #include "session_p.h"
 #include "rfccodecs.h"
 
-namespace KIMAP2
+namespace KIMAP
 {
 class SelectJobPrivate : public JobPrivate
 {
@@ -52,10 +53,10 @@ public:
 };
 }
 
-using namespace KIMAP2;
+using namespace KIMAP;
 
 SelectJob::SelectJob(Session *session)
-    : Job(*new SelectJobPrivate(session, "Select"))
+    : Job(*new SelectJobPrivate(session, i18nc("name of the select job", "Select")))
 {
 }
 
@@ -156,13 +157,13 @@ void SelectJob::doStart()
         command = "EXAMINE";
     }
 
-    QByteArray params = '\"' + KIMAP2::encodeImapFolderName(d->mailBox.toUtf8()) + '\"';
+    QByteArray params = '\"' + KIMAP::encodeImapFolderName(d->mailBox.toUtf8()) + '\"';
 
     if (d->condstoreEnabled) {
         params += " (CONDSTORE)";
     }
 
-    d->sendCommand(command, params);
+    d->tags << d->sessionInternal()->sendCommand(command, params);
 }
 
 void SelectJob::handleResponse(const Message &response)
@@ -220,7 +221,7 @@ void SelectJob::handleResponse(const Message &response)
                 }
             }
         } else {
-            qCDebug(KIMAP2_LOG) << response.toString();
+            qCDebug(KIMAP_LOG) << response.toString();
         }
     } else {
         Q_ASSERT(error() || d->m_session->selectedMailBox() == d->mailBox);
